package zero1hd.polyjet.entity.enemies;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.badlogic.gdx.math.Rectangle;
import com.badlogic.gdx.math.Vector2;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.utils.Pool.Poolable;

import zero1hd.polyjet.entity.Entities;
import zero1hd.polyjet.entity.Entity;

public class VoidCircle extends Actor implements Entity, Poolable {
	private float warnTime;
	private float timer;
	private float endRadius;
	private float currentRadius;
	private Rectangle hitBox;
	private ShapeRenderer shapeRenderer;
	private float growthRate;
	private boolean done;
	private boolean begin;
	private Vector2 center;
	
public VoidCircle(ShapeRenderer shapeRenderer) {
		hitBox = new Rectangle();
		this.shapeRenderer = shapeRenderer;
		center = new Vector2();
	}
	
	public void init(float endRadius, float x, float y, float growthRate, float warningTime) {
		timer = warningTime;
		warnTime = warningTime;
		this.endRadius = endRadius;
		setSize(2f*endRadius, 2f*endRadius);
		center.set(getWidth()/2f, getHeight()/2f);
		setPosition(x-center.x, y-center.y);
		this.growthRate = growthRate;
	}
	
	@Override
	public void act(float delta) {
		toFront();
		hitBox.setCenter(getX()+center.x, getY()+center.y);
		
		if (timer > 0) {
			timer -= delta;
		} else {
			begin = true;
			if (currentRadius < endRadius) {
				growCurrentRadius(delta*growthRate);
			} else {
				endRadius = -1f;
				if (currentRadius > 0) {
					growCurrentRadius(delta*-3*growthRate);
				} else {
					done = true;
				}
			}
		}
		super.act(delta);
	}
	
	
	@Override
	public void draw(Batch batch, float parentAlpha) {
		batch.end();
		shapeRenderer.begin();
		if (begin) {
			shapeRenderer.set(ShapeType.Filled);
			shapeRenderer.setColor(Color.BLACK);
			shapeRenderer.circle(getX()+center.x, getY()+center.y, currentRadius, 48);
		} else {
			shapeRenderer.set(ShapeType.Line);
			shapeRenderer.setColor(1 - timer/warnTime, 1 - timer/warnTime, 1 - timer/warnTime, 1f);
			shapeRenderer.circle(getX()+center.x, getY()+center.y, endRadius, 48);
		}
		shapeRenderer.end();
		batch.begin();
		
		
		super.draw(batch, parentAlpha);
	}
	
	@Override
	public void reset() {
		hitBox.set(0, 0, 0, 0);
		currentRadius = 0;
		growthRate = 0;
		timer = 0;
		endRadius = 0;
		done = false;
		begin = false;
		warnTime = 0;
		center.set(0, 0);
		setSize(0, 0);
	}
	
	public void growCurrentRadius(float radius) {
		currentRadius += radius;
		float length = (float) Math.sqrt(2*(currentRadius*currentRadius));
		hitBox.setSize(length, length);
	}
	
	@Override
	public Rectangle getHitZone() {
		return hitBox;
	}

	@Override
	public Entities getEntityType() {
		return Entities.VOID_CIRCLE;
	}

	@Override
	public void collided(Entity entity) {
	}

	@Override
	public boolean isDead() {
		return done;
	}
}
